/**
 * Copyright (c) 2009-2012, Netbout.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are PROHIBITED without prior written permission from
 * the author. This product may NOT be used anywhere and on any computer
 * except the server platform of netBout Inc. located at www.netbout.com.
 * Federal copyright law prohibits unauthorized reproduction by any means
 * and imposes fines up to $25,000 for violation. If you received
 * this code occasionally and without intent to use it, please report this
 * incident to the author by email.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package com.netbout.inf;

import org.mockito.Mockito;
import org.mockito.invocation.InvocationOnMock;
import org.mockito.stubbing.Answer;

/**
 * Mocker of {@link Cursor}.
 * @author Yegor Bugayenko (yegor@netbout.com)
 * @version $Id$
 */
public final class CursorMocker {

    /**
     * The object.
     */
    private final transient Cursor cursor = Mockito.mock(Cursor.class);

    /**
     * Public ctor.
     */
    public CursorMocker() {
        this.withMsg(new MsgMocker().mock());
    }

    /**
     * With this message.
     * @param msg The msg
     * @return This object
     */
    public CursorMocker withMsg(final Msg msg) {
        Mockito.doReturn(msg).when(this.cursor).msg();
        Mockito.doReturn(false).when(this.cursor).end();
        return this;
    }

    /**
     * With this message.
     * @param msg The msg
     * @return This object
     */
    public CursorMocker withMsg(final long msg) {
        return this.withMsg(new MsgMocker().withNumber(msg).mock());
    }

    /**
     * Always shift to this msg.
     * @param msg The msg to shift to
     * @return This object
     */
    public CursorMocker shiftTo(final long msg) {
        return this.shiftTo(new CursorMocker().withMsg(msg).mock());
    }

    /**
     * Always shift to this msg.
     * @param crsr The cursor to shift to
     * @return This object
     */
    public CursorMocker shiftTo(final Cursor crsr) {
        Mockito.doAnswer(
            new Answer<Cursor>() {
                public Cursor answer(final InvocationOnMock invocation) {
                    return crsr;
                }
            }
        ).when(this.cursor).shift(Mockito.any(Term.class));
        return this;
    }

    /**
     * Build it.
     * @return The cursor
     */
    public Cursor mock() {
        return this.cursor;
    }

}
